#
# spec file for package ghc-HaTeX
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name HaTeX
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        3.17.3.1
Release:        6.1
Summary:        The Haskell LaTeX library
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-matrix-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-wl-pprint-extras-devel
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
This library implements the LaTeX syntax and provides some useful abstractions.

Some of the things you can do with HaTeX are:

* Write LaTeX documents with all the advantages you already have in Haskell:
recursion, type system, high order functions, ...

* Create a LaTeX backend for your own program.

* Parse a LaTeX file and obtain its Abstract Syntax Tree (AST).

* Pretty-print Haskell values in LaTeX.

* Generate TikZ scripts (images!) easily.

Browse the 'examples' directory in the source distribution to see some simple
examples. It might help you to get started. The HaTeX User's Guide is available
at <https://github.com/Daniel-Diaz/hatex-guide/blob/master/README.md>.
We also have a mailing list
(<http://projects.haskell.org/cgi-bin/mailman/listinfo/hatex>) and an IRC
channel ('#hatex'). If you just want to read a short introduction, read the
"Text.LaTeX" module.

If you prefer to write in LaTeX and all you want is to /program/ some parts of
the document, or if you already have the LaTeX document written and you just
want to add some automatically generated LaTeX code somewhere, check haskintex:
<http://daniel-diaz.github.io/projects/haskintex>. It allows you to embed
Haskell in LaTeX. It also makes you easy to use HaTeX within a LaTeX document.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc license

%files devel -f %{name}-devel.files
%doc CHANGELOG.md Examples README.md docfiles

%changelog
* Thu Aug 17 2017 psimons@suse.com
- Update to version 3.17.3.1.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 3.17.3.0.
* Wed May  3 2017 psimons@suse.com
- Update to version 3.17.2.0 with cabal2obs.
* Mon Jan  9 2017 psimons@suse.com
- Update to version 3.17.1.0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 3.17.0.2 revision 0 with cabal2obs.
